/* Lasem
 *
 * Copyright © 2009-10 Emmanuel Pacaud
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1335, USA.
 *
 * Author:
 * 	Emmanuel Pacaud <emmanuel@gnome.org>
 */

#ifndef LSM_SVG_H
#define LSM_SVG_H

#include <lsmdom.h>

#include <lsmsvgtypes.h>

#include <lsmsvgtraits.h>
#include <lsmsvgattributes.h>
#include <lsmsvgstyle.h>
#include <lsmsvgcolors.h>
#include <lsmsvglength.h>
#include <lsmsvgview.h>
#include <lsmsvgmatrix.h>
#include <lsmsvgdocument.h>
#include <lsmsvgelement.h>
#include <lsmsvgclippathelement.h>
#include <lsmsvgsvgelement.h>
#include <lsmsvggelement.h>
#include <lsmsvgdefselement.h>
#include <lsmsvguseelement.h>
#include <lsmsvgimageelement.h>
#include <lsmsvgsymbolelement.h>
#include <lsmsvgmarkerelement.h>
#include <lsmsvgrectelement.h>
#include <lsmsvgcircleelement.h>
#include <lsmsvgellipseelement.h>
#include <lsmsvglineelement.h>
#include <lsmsvgpathelement.h>
#include <lsmsvgpolylineelement.h>
#include <lsmsvgpolygonelement.h>
#include <lsmsvgtextelement.h>
#include <lsmsvgtspanelement.h>
#include <lsmsvggradientelement.h>
#include <lsmsvglineargradientelement.h>
#include <lsmsvgradialgradientelement.h>
#include <lsmsvgstopelement.h>
#include <lsmsvgpatternelement.h>
#include <lsmsvgmaskelement.h>
#include <lsmsvgfilterelement.h>
#include <lsmsvgfilterprimitive.h>
#include <lsmsvgfiltergaussianblur.h>

#endif
